@@ -2,8 +2,8 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2022 Osimis S.A., Belgium
- * Copyright (C) 2021-2022 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2017-2024 Osimis S.A., Belgium
+ * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -37,6 +37,8 @@
 #include <EmbeddedResources.h>
 #include <boost/filesystem.hpp>
 
+#define ORTHANC_PLUGIN_NAME "web-viewer"
+
 
 /**
  * We force the redefinition of the "ORTHANC_PLUGINS_API" macro, that
@@ -418,7 +420,7 @@ extern "C"
       return -1;
     }
 
-    OrthancPluginSetDescription(context, "Provides a Web viewer of DICOM series within Orthanc.");
+    OrthancPlugins::SetDescription(ORTHANC_PLUGIN_NAME, "Provides a Web viewer of DICOM series within Orthanc.");
 
 
     /* By default, use half of the available processing cores for the decoding of DICOM images */
@@ -535,7 +537,7 @@ extern "C"
     /* Extend the default Orthanc Explorer with custom JavaScript */
     std::string explorer;
     Orthanc::EmbeddedResources::GetFileResource(explorer, Orthanc::EmbeddedResources::ORTHANC_EXPLORER);
-    OrthancPluginExtendOrthancExplorer(context, explorer.c_str());
+    OrthancPlugins::ExtendOrthancExplorer(ORTHANC_PLUGIN_NAME, explorer);
 
     return 0;
   }
@@ -557,7 +559,7 @@ extern "C"
 
   ORTHANC_PLUGINS_API const char* OrthancPluginGetName()
   {
-    return "web-viewer";
+    return ORTHANC_PLUGIN_NAME;
   }
 
 
